==> sinosun-ui-0.1.4.tgz: package/es/modal/modal.js <==
import { PopupMixin } from '../mixins/popup';
import Button from '../button';
import classNames from '../_utils/classnames';

var Modal = {
    mixins: [PopupMixin],

    props: {
        title: String,
        width: [Number, String],
        message: String,
        className: null,
        callback: Function,
        beforeClose: Function,
        messageAlign: String,
        cancelButtonText: {
            type: String,
            'default': '取消'
        },
        cancelButtonColor: String,
        confirmButtonText: {
            type: String,
            'default': '确认'
        },
        confirmButtonColor: String,
        showCancelButton: Boolean,
        transition: {
            type: String,
            'default': 'sn-modal-bounce'
        },
        showConfirmButton: {
            type: Boolean,
            'default': true
        },
        overlay: {
            type: Boolean,
            'default': true
        },
        closeOnClickOverlay: {
            type: Boolean,
            'default': false
        }
    },

    data: function data() {
        return {
            loading: {
                confirm: false,
                cancel: false
            }
        };
    },


    methods: {
        onClickOverlay: function onClickOverlay() {
            this.handleAction('overlay');
        },
        handleAction: function handleAction(action) {
            var _this = this;

            this.$emit(action);

            if (this.beforeClose) {
                this.loading[action] = true;
                this.beforeClose(action, function (state) {
                    if (state !== false && _this.loading[action]) {
                        _this.onClose(action);
                    }

                    _this.loading.confirm = false;
                    _this.loading.cancel = false;
                });
            } else {
                this.onClose(action);
            }
        },
        onClose: function onClose(action) {
            this.close();

            if (this.callback) {
                this.callback(action);
            }
        },
        onOpened: function onOpened() {
            this.$emit('opened');
        },
        onClosed: function onClosed() {
            this.$emit('closed');
        }
    },

    render: function render() {
        var _this2 = this;

        var h = arguments[0];

        if (!this.shouldRender) {
            return;
        }

        var message = this.message,
            messageAlign = this.messageAlign,
            confirmButtonText = this.confirmButtonText,
            $slots = this.$slots;

        var messageSlot = $slots['default'];
        var title = $slots['title'] || this.title;

        var Title = title && h(
            'div',
            { 'class': {
                    'sn-modal-header': true,
                    isolated: !message && !messageSlot
                } },
            [title]
        );

        var Content = (messageSlot || message) && h(
            'div',
            { 'class': 'sn-modal-content' },
            [messageSlot || h('div', {
                domProps: {
                    'innerHTML': message
                },

                'class': classNames('sn-modal-message', 'sn-modal-message-' + messageAlign)
            })]
        );

        var hasButtons = this.showCancelButton && this.showConfirmButton;
        var ButtonGroup = h(
            'div',
            { 'class': {
                    'sn-modal-footer': true,
                    'sn-modal-footer-button-group': hasButtons
                } },
            [this.showCancelButton && h(
                Button,
                {
                    attrs: {
                        shape: 'square',

                        loading: this.loading.cancel
                    },
                    'class': 'sn-modal-footer-cancel', style: { color: this.cancelButtonColor },
                    on: {
                        'click': function click() {
                            return _this2.handleAction('cancel');
                        }
                    }
                },
                [this.cancelButtonText]
            ), this.showConfirmButton && h(
                Button,
                {
                    attrs: {
                        shape: 'square',

                        loading: this.loading.confirm
                    },
                    'class': 'sn-modal-footer-confirm', style: { color: this.confirmButtonColor },
                    on: {
                        'click': function click() {
                            return _this2.handleAction('confirm');
                        }
                    }
                },
                [confirmButtonText]
            )]
        );

        return h(
            'transition',
            {
                attrs: {
                    name: this.transition
                },
                on: {
                    'afterEnter': this.onOpened,
                    'afterLeave': this.onClosed
                }
            },
            [h(
                'div',
                {
                    directives: [{
                        name: 'show',
                        value: this.value
                    }],
                    attrs: {
                        role: 'modal'
                    },
                    'class': classNames('sn-modal', this.className),
                    style: { width: this.width }
                },
                [Title, Content, ButtonGroup]
            )]
        );
    }
};

export default Modal;

==> sinosun-ui-0.2.6.tgz: package/es/modal/modal.js <==
import _defineProperty from 'babel-runtime/helpers/defineProperty';
import { PopupMixin } from '../mixins/popup';
import Button from '../button';
import classNames from '../_utils/classnames';
import { isPC } from '../utils/commonUtil';

var Modal = {
    mixins: [PopupMixin],

    props: {
        title: String,
        width: [Number, String],
        message: String,
        className: null,
        callback: Function,
        beforeClose: Function,
        messageAlign: String,
        cancelButtonText: {
            type: String,
            'default': '取消'
        },
        cancelButtonColor: String,
        confirmButtonText: {
            type: String,
            'default': '确认'
        },
        confirmButtonColor: String,
        showCancelButton: Boolean,
        transition: {
            type: String,
            'default': 'sn-modal-bounce'
        },
        showConfirmButton: {
            type: Boolean,
            'default': true
        },
        overlay: {
            type: Boolean,
            'default': true
        },
        closeOnClickOverlay: {
            type: Boolean,
            'default': false
        }
    },

    data: function data() {
        return {
            loading: {
                confirm: false,
                cancel: false
            },
            height: null,
            multiLine: false
        };
    },


    watch: {
        message: function message() {
            var _this = this;

            this.$nextTick(function () {
                var $message = _this.$refs.message;
                if ($message && $message instanceof HTMLElement) {
                    var height = parseInt(window.getComputedStyle($message).height);
                    _this.multiLine = height > 30;
                }
            });
        }
    },

    methods: {
        onClickOverlay: function onClickOverlay() {
            this.handleAction('overlay');
        },
        handleAction: function handleAction(action) {
            var _this2 = this;

            this.$emit(action);

            if (this.beforeClose) {
                this.loading[action] = true;
                this.beforeClose(action, function (state) {
                    if (state !== false && _this2.loading[action]) {
                        _this2.onClose(action);
                    }

                    _this2.loading.confirm = false;
                    _this2.loading.cancel = false;
                });
            } else {
                this.onClose(action);
            }
        },
        updateModal: function updateModal() {
            var _this3 = this;

            this.$nextTick(function () {
                var $modal = _this3.$refs.modal;
                if ($modal && $modal instanceof HTMLElement) {
                    var height = parseInt(window.getComputedStyle($modal).height);
                    if (height % 2 === 1) height++;
                    _this3.height = height + 'px';
                }
            });
        },
        onClose: function onClose(action) {
            this.close();

            if (this.callback) {
                this.callback(action);
            }
        },
        onOpened: function onOpened() {
            isPC() && this.updateModal();
            this.$emit('opened');
        },
        onClosed: function onClosed() {
            this.height = null;
            this.$emit('closed');
        }
    },

    render: function render() {
        var _ref,
            _this4 = this;

        var h = arguments[0];

        if (!this.shouldRender) {
            return;
        }

        var value = this.value,
            width = this.width,
            height = this.height,
            className = this.className,
            message = this.message,
            messageAlign = this.messageAlign,
            confirmButtonText = this.confirmButtonText,
            multiLine = this.multiLine,
            $slots = this.$slots;

        var title = $slots['title'] || this.title;

        var Title = title && h(
            'div',
            { 'class': {
                    'sn-modal-header': true,
                    'sn-modal-header-content': message
                } },
            [title]
        );

        var Content = message && h(
            'div',
            { 'class': 'sn-modal-content' },
            [h(
                'div',
                {
                    ref: 'message',
                    'class': (_ref = {
                        'sn-modal-message': true
                    }, _defineProperty(_ref, 'sn-modal-message-' + messageAlign, messageAlign), _defineProperty(_ref, 'sn-modal-message-left', multiLine), _ref)
                },
                [message]
            )]
        );

        var hasButtons = this.showCancelButton && this.showConfirmButton;
        var ButtonGroup = h(
            'div',
            { 'class': {
                    'sn-modal-footer': true,
                    'sn-modal-footer-button-group': hasButtons
                } },
            [this.showCancelButton && h(
                Button,
                {
                    attrs: {
                        shape: 'square',

                        loading: this.loading.cancel
                    },
                    'class': 'sn-modal-footer-cancel', style: { color: this.cancelButtonColor },
                    on: {
                        'click': function click() {
                            return _this4.handleAction('cancel');
                        }
                    }
                },
                [this.cancelButtonText]
            ), this.showConfirmButton && h(
                Button,
                {
                    attrs: {
                        shape: 'square',

                        loading: this.loading.confirm
                    },
                    'class': 'sn-modal-footer-confirm', style: { color: this.confirmButtonColor },
                    on: {
                        'click': function click() {
                            return _this4.handleAction('confirm');
                        }
                    }
                },
                [confirmButtonText]
            )]
        );

        return h(
            'transition',
            {
                attrs: {
                    name: this.transition
                },
                on: {
                    'afterEnter': this.onOpened,
                    'afterLeave': this.onClosed
                }
            },
            [h(
                'div',
                {
                    ref: 'modal',
                    directives: [{
                        name: 'show',
                        value: value
                    }],
                    attrs: {
                        role: 'modal'
                    },
                    'class': classNames('sn-modal', className),
                    style: { width: width, height: height }
                },
                [Title, Content, ButtonGroup]
            )]
        );
    }
};

export default Modal;
